#[non_exhaustive]pub enum ReferenceOnlyOpenings {
Refuse,
TakeAsApplied,
}Expand description
What lower_product_net_with does with an opening that has only a
Reference representation (#351).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Refuse
Refuse the host with GeometryError::OpeningNotSubtracted, as
lower_product_net does. The default.
TakeAsApplied
Report the opening in NetLowering::taken_as_applied and subtract
nothing for it: the host’s Body is taken to carry the void already.