pub fn validate_model(model: &Model) -> Vec<RuleViolation>Expand description
Validate every entity in a model.
Linear in model size and allocation-free unless a rule actually fails, so it is cheap enough to run as an import-time check.
pub fn validate_model(model: &Model) -> Vec<RuleViolation>Validate every entity in a model.
Linear in model size and allocation-free unless a rule actually fails, so it is cheap enough to run as an import-time check.