UnitScale

Struct UnitScale 

pub struct UnitScale {
    pub length_to_metres: f64,
    pub angle_to_radians: f64,
}
Multipliers converting file units into SI base units.

Fields

length_to_metres: f64

Multiply a stored length by this to get metres.

angle_to_radians: f64

Multiply a stored plane angle by this to get radians.

Implementations

Source

impl UnitScale

pub fn length(&self, value: f64) -> f64

Convert a stored length to metres.

pub fn angle(&self, value: f64) -> f64

Convert a stored plane angle to radians.

pub fn is_metric_identity(&self) -> bool

Are lengths already in metres?