pub struct UnitScale {
pub length_to_metres: f64,
pub angle_to_radians: f64,
}Expand description
Multipliers converting file units into SI base units.
Fields
length_to_metres: f64Multiply a stored length by this to get metres.
angle_to_radians: f64Multiply a stored plane angle by this to get radians.
Implementations